==> nextcloud-16.0.5.tgz: nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Hi ha disponible la versió {version}. Obtingueu més informació sobre com actualitzar.",
    "Channel updated" : "Canal actualitzat",
    "Update notifications" : "Notificacions d'actualització",
    "The update server could not be reached since %d days to check for new updates." : "No s’ha pogut accedir al servidor d’actualitzacions des de fa %d dies per comprovar si hi ha actualitzacions noves.",
    "Please check the Nextcloud and server log files for errors." : "Si us plau, comproveu els fitxers de registre del servidor i del Nextcloud per detectar errors.",
    "Update to %1$s is available." : "Hi ha disponible l'actualització per %1$s.",
    "Update for %1$s to version %2$s is available." : "Hi ha disponible l'actualització a la versió %2$s per %1$s.",
    "Update for {app} to version %s is available." : "Hi ha disponible l'actualització a la versió %s per {app}.",
    "Update notification" : "Notificació d'actualització",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Mostra les notificacions d’actualització de Nextcloud i proporciona l’SSO de l’actualitzador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versió que esteu executant ja no es manté. Assegureu-vos d’actualitzar el més aviat possible a una versió suportada.",
    "Apps missing updates" : "Les aplicacions no tenen actualitzacions",
    "View in store" : "Mostra-ho al magatzem",
    "Apps with available updates" : "Aplicacions amb actualitzacions disponibles",
    "Open updater" : "Obre l'actualitzador",
    "Download now" : "Descarrega-ho ara",
    "What's new?" : "Quines novetats hi ha?",
    "The update check is not yet finished. Please refresh the page." : "La comprovació de l’actualització encara no ha finalitzat. Si us plau, actualitzeu la pàgina.",
    "Your version is up to date." : "La vostra versió està actualitzada.",
    "A non-default update server is in use to be checked for updates:" : "Es fa servir un servidor d’actualització no predeterminat per comprovar si hi ha actualitzacions:",
    "Update channel:" : "Actualitza el canal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre podeu actualitzar a una versió més recent. Però mai no podeu baixar a una versió més estable.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Tingueu en compte que després d'un nou llançament, pot trigar un temps abans que aparegui aquí. Despleguem noves versions distribuïdes amb el temps als nostres usuaris i, de vegades, ometem una versió quan es detecten problemes.",
    "Notify members of the following groups about available updates:" : "Notifica als membres dels següents grups sobre les actualitzacions disponibles:",
    "Only notification for app updates are available." : "Només hi ha disponible notificacions per actualitzacions d’aplicacions.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualització seleccionat deixa obsoletes les notificacions específiques del servidor.",
    "The selected update channel does not support updates of the server." : "El canal d'actualització seleccionat no admet actualitzacions del servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hi ha una nova versió disponible: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Verificat el {lastCheckedDate}",
    "Checking apps for compatible updates" : "S'estàn comprovant aplicacions per a actualitzacions compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Si us plau, assegureu-vos que en el vostre config.php no s'ha establert <samp>appstoreenabled</samp> com a fals.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "No s’ha pogut connectar amb el magatzem d’aplicacions o aquest no ha retornat cap actualització. Cerqueu manualment actualitzacions o assegureu-vos que el vostre servidor tingui accés a Internet i es pugui connectar al magatzem d'aplicacions.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Totes</strong> les aplicacions tenen una actualització disponible per aquesta versió",
    "View changelog" : "Mostra el registre de canvis",
    "Enterprise" : "Empresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per ús empresarial. Proporciona sempre el nivell de patch més recent, però no s'actualitzarà immediatament a la propera versió principal. Aquesta actualització es produeix quan Nextcloud GmbH ha realitzat proves i enduriments addicionals per a implementacions a gran escala i de missions crítiques. Aquest canal només està disponible per als clients i proporciona el paquet Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versió estable més recent. És adequat per un ús normal i sempre s'actualitzarà a la versió més recent.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versió prèvia a la publicació només per provar noves funcions, no per a entorns de producció.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplicació no té cap actualització disponible per aquesta versió.","<strong>%n</strong> aplicacions no tenen cap actualització disponible per aquesta versió."],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Sempre podeu actualitzar a una versió més recent / canal experimental. Però mai no es pot fer un \"downgrade\" a un canal més estable.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>producció</strong> sempre proporcionarà el nivell de pedaç més recent, però no s'actualitzarà immediatament a la propera versió principal. Aquesta actualització sol passar amb el llençament de la segona versió menor (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>estable</strong> és la versió estable més recent. És adequada per un ús normal i sempre s'actualitzarà a la versió principal més recent.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>beta</strong> és una versió prèvia a la publicació només per provar noves funcions, no pas per a entorns de producció.",
    "Production" : "Producció",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Sempre proporcionarà el nivell de pedaç més recent, però no s'actualitzarà immediatament a la propera versió principal. Aquesta actualització sol passar amb la segona versió menor (x.0.2) i només si la instància ja és a la darrera versió menor."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.4.tgz: nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Hi ha disponible la versió {version}. Obtingueu més informació sobre com actualitzar.",
    "Channel updated" : "S'ha actualitzat el canal.",
    "Update notifications" : "Notificacions d'actualització",
    "The update server could not be reached since %d days to check for new updates." : "No s’ha pogut accedir al servidor d’actualitzacions des de fa %d dies per comprovar si hi ha actualitzacions noves.",
    "Please check the Nextcloud and server log files for errors." : "Si us plau, comproveu els fitxers de registre del servidor i del Nextcloud per detectar errors.",
    "Update to %1$s is available." : "Hi ha disponible l'actualització a %1$s.",
    "Update for %1$s to version %2$s is available." : "Hi ha disponible l'actualització a la versió %2$s per a %1$s.",
    "Update for {app} to version %s is available." : "Hi ha disponible l'actualització a la versió %s per a {app}.",
    "Update notification" : "Notificació d'actualització",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Mostra les notificacions d’actualització de Nextcloud i proporciona l’SSO de l’actualitzador.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versió que esteu executant ja no es manté. Assegureu-vos d’actualitzar el més aviat possible a una versió suportada.",
    "Apps missing updates" : "Les aplicacions no tenen actualitzacions",
    "View in store" : "Mostra-ho al magatzem",
    "Apps with available updates" : "Aplicacions amb actualitzacions disponibles",
    "Open updater" : "Obre l'actualitzador",
    "Download now" : "Descarrega-ho ara",
    "What's new?" : "Quines novetats hi ha?",
    "The update check is not yet finished. Please refresh the page." : "La comprovació de l’actualització encara no ha finalitzat. Si us plau, actualitzeu la pàgina.",
    "Your version is up to date." : "La vostra versió està actualitzada.",
    "A non-default update server is in use to be checked for updates:" : "Es fa servir un servidor d’actualització no predeterminat per comprovar si hi ha actualitzacions:",
    "Update channel:" : "Canal d'actualitzacions:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre podeu actualitzar a una versió més recent. Però mai no podeu baixar a una versió més estable.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Tingueu en compte que després d'un nou llançament, pot trigar un temps abans que aparegui aquí. Despleguem noves versions distribuïdes amb el temps als nostres usuaris i, de vegades, ometem una versió quan es detecten problemes.",
    "Notify members of the following groups about available updates:" : "Notifica als membres dels següents grups sobre les actualitzacions disponibles:",
    "Only notification for app updates are available." : "Només hi ha disponible notificacions per actualitzacions d’aplicacions.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualització seleccionat deixa obsoletes les notificacions específiques del servidor.",
    "The selected update channel does not support updates of the server." : "El canal d'actualitzacions seleccionat no admet les actualitzacions del servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hi ha una nova versió disponible: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Verificat el {lastCheckedDate}",
    "Checking apps for compatible updates" : "S'estàn comprovant aplicacions per a actualitzacions compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Si us plau, assegureu-vos que en el vostre config.php no s'ha establert <samp>appstoreenabled</samp> com a fals.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "No s’ha pogut connectar amb el magatzem d’aplicacions o aquest no ha retornat cap actualització. Cerqueu manualment actualitzacions o assegureu-vos que el vostre servidor tingui accés a Internet i es pugui connectar al magatzem d'aplicacions.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Totes</strong> les aplicacions tenen una actualització disponible per aquesta versió",
    "View changelog" : "Mostra el registre de canvis",
    "Enterprise" : "Empresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Per ús empresarial. Proporciona sempre el nivell de patch més recent, però no s'actualitzarà immediatament a la propera versió principal. Aquesta actualització es produeix quan Nextcloud GmbH ha realitzat proves i enduriments addicionals per a implementacions a gran escala i de missions crítiques. Aquest canal només està disponible per als clients i proporciona el paquet Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versió estable més recent. És adequat per un ús normal i sempre s'actualitzarà a la versió més recent.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versió prèvia a la publicació només per provar noves funcions, no per a entorns de producció.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplicació no té cap actualització disponible per aquesta versió.","<strong>%n</strong> aplicacions no tenen cap actualització disponible per aquesta versió."]
},
"nplurals=2; plural=(n != 1);");
